Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(883)

Unified Diff: content/browser/download/download_file_impl.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/download/download_file_impl.h
diff --git a/content/browser/download/download_file_impl.h b/content/browser/download/download_file_impl.h
index 2fcb6bda557a6bc06e62f1f3780d84982c6aaa53..fbe5c1a48f842e0dc518f2791f7a3bfeaab12337 100644
--- a/content/browser/download/download_file_impl.h
+++ b/content/browser/download/download_file_impl.h
@@ -33,7 +33,7 @@ struct DownloadCreateInfo;
class CONTENT_EXPORT DownloadFileImpl : public DownloadFile {
public:
// Takes ownership of the object pointed to by |request_handle|.
// |bound_net_log| will be used for logging the download file's events.
// May be constructed on any thread. All methods besides the constructor
// (including destruction) must occur on the FILE thread.
//
@@ -43,7 +43,7 @@ class CONTENT_EXPORT DownloadFileImpl : public DownloadFile {
DownloadFileImpl(std::unique_ptr<DownloadSaveInfo> save_info,
const base::FilePath& default_downloads_directory,
std::unique_ptr<ByteStreamReader> byte_stream,
- const net::BoundNetLog& bound_net_log,
+ const net::NetLogWithSource& net_log,
base::WeakPtr<DownloadDestinationObserver> observer);
~DownloadFileImpl() override;
@@ -113,7 +113,7 @@ class CONTENT_EXPORT DownloadFileImpl : public DownloadFile {
// handled.
void StreamActive();
- net::BoundNetLog bound_net_log_;
+ net::NetLogWithSource net_log_;
// The base file instance.
BaseFile file_;
@@ -33,7 +33,7 @@ struct DownloadCreateInfo;
public:
// Takes ownership of the object pointed to by |request_handle|.
- // |bound_net_log| will be used for logging the download file's events.
+ // |net_log| will be used for logging the download file's events.
// May be constructed on any thread. All methods besides the constructor
// (including destruction) must occur on the FILE thread.

Powered by Google App Engine
This is Rietveld 408576698